@@ -15,6 +15,7 @@ import zope.component
 
 from acme import fields as acme_fields
 from acme import messages
+from acme.client import ClientBase  # pylint: disable=unused-import
 from certbot import errors
 from certbot import interfaces
 from certbot import util
@@ -39,6 +40,8 @@ class Account(object):
 
         :ivar datetime.datetime creation_dt: Creation date and time (UTC).
         :ivar str creation_host: FQDN of host, where account has been created.
+        :ivar str register_to_eff: If not None, Certbot will register the provided
+                                        email during the account registration.
 
         .. note:: ``creation_dt`` and ``creation_host`` are useful in
             cross-machine migration scenarios.
@@ -46,21 +49,29 @@ class Account(object):
         """
         creation_dt = acme_fields.RFC3339Field("creation_dt")
         creation_host = jose.Field("creation_host")
+        register_to_eff = jose.Field("register_to_eff", omitempty=True)
 
     def __init__(self, regr, key, meta=None):
         self.key = key
         self.regr = regr
         self.meta = self.Meta(
             # pyrfc3339 drops microseconds, make sure __eq__ is sane
-            creation_dt=datetime.datetime.now(
-                tz=pytz.UTC).replace(microsecond=0),
-            creation_host=socket.getfqdn()) if meta is None else meta
+            creation_dt=datetime.datetime.now(tz=pytz.UTC).replace(microsecond=0),
+            creation_host=socket.getfqdn(),
+            register_to_eff=None) if meta is None else meta
 
-        self.id = hashlib.md5(
-            self.key.key.public_key().public_bytes(
-                encoding=serialization.Encoding.PEM,
-                format=serialization.PublicFormat.SubjectPublicKeyInfo)
-        ).hexdigest()
+        # try MD5, else use MD5 in non-security mode (e.g. for FIPS systems / RHEL)
+        try:
+            hasher = hashlib.md5()
+        except ValueError:
+            hasher = hashlib.new('md5', usedforsecurity=False) # type: ignore
+
+        hasher.update(self.key.key.public_key().public_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PublicFormat.SubjectPublicKeyInfo)
+        )
+
+        self.id = hasher.hexdigest()
         # Implementation note: Email? Multiple accounts can have the
         # same email address. Registration URI? Assigned by the
         # server, not guaranteed to be stable over time, nor
@@ -235,15 +246,47 @@ class AccountFileStorage(interfaces.AccountStorage):
         return self._load_for_server_path(account_id, self.config.server_path)
 
     def save(self, account, client):
-        self._save(account, client, regr_only=False)
+        # type: (Account, ClientBase) -> None
+        """Create a new account.
 
-    def save_regr(self, account, acme):
-        """Save the registration resource.
-
-        :param Account account: account whose regr should be saved
+        :param Account account: account to create
+        :param ClientBase client: ACME client associated to the account
 
         """
-        self._save(account, acme, regr_only=True)
+        try:
+            dir_path = self._prepare(account)
+            self._create(account, dir_path)
+            self._update_meta(account, dir_path)
+            self._update_regr(account, client, dir_path)
+        except IOError as error:
+            raise errors.AccountStorageError(error)
+
+    def update_regr(self, account, client):
+        # type: (Account, ClientBase) -> None
+        """Update the registration resource.
+
+        :param Account account: account to update
+        :param ClientBase client: ACME client associated to the account
+
+        """
+        try:
+            dir_path = self._prepare(account)
+            self._update_regr(account, client, dir_path)
+        except IOError as error:
+            raise errors.AccountStorageError(error)
+
+    def update_meta(self, account):
+        # type: (Account) -> None
+        """Update the meta resource.
+
+        :param Account account: account to update
+
+        """
+        try:
+            dir_path = self._prepare(account)
+            self._update_meta(account, dir_path)
+        except IOError as error:
+            raise errors.AccountStorageError(error)
 
     def delete(self, account_id):
         """Delete registration info from disk
@@ -311,32 +354,36 @@ class AccountFileStorage(interfaces.AccountStorage):
 
         return dir_path
 
-    def _save(self, account, acme, regr_only):
+    def _prepare(self, account):
+        # type: (Account) -> str
         account_dir_path = self._account_dir_path(account.id)
         util.make_or_verify_dir(account_dir_path, 0o700, self.config.strict_permissions)
-        try:
-            with open(self._regr_path(account_dir_path), "w") as regr_file:
-                regr = account.regr
-                # If we have a value for new-authz, save it for forwards
-                # compatibility with older versions of Certbot. If we don't
-                # have a value for new-authz, this is an ACMEv2 directory where
-                # an older version of Certbot won't work anyway.
-                if hasattr(acme.directory, "new-authz"):
-                    regr = RegistrationResourceWithNewAuthzrURI(
-                        new_authzr_uri=acme.directory.new_authz,
-                        body={},
-                        uri=regr.uri)
-                else:
-                    regr = messages.RegistrationResource(
-                        body={},
-                        uri=regr.uri)
-                regr_file.write(regr.json_dumps())
-            if not regr_only:
-                with util.safe_open(self._key_path(account_dir_path),
-                                    "w", chmod=0o400) as key_file:
-                    key_file.write(account.key.json_dumps())
-                with open(self._metadata_path(
-                        account_dir_path), "w") as metadata_file:
-                    metadata_file.write(account.meta.json_dumps())
-        except IOError as error:
-            raise errors.AccountStorageError(error)
+        return account_dir_path
+
+    def _create(self, account, dir_path):
+        # type: (Account, str) -> None
+        with util.safe_open(self._key_path(dir_path), "w", chmod=0o400) as key_file:
+            key_file.write(account.key.json_dumps())
+
+    def _update_regr(self, account, acme, dir_path):
+        # type: (Account, ClientBase, str) -> None
+        with open(self._regr_path(dir_path), "w") as regr_file:
+            regr = account.regr
+            # If we have a value for new-authz, save it for forwards
+            # compatibility with older versions of Certbot. If we don't
+            # have a value for new-authz, this is an ACMEv2 directory where
+            # an older version of Certbot won't work anyway.
+            if hasattr(acme.directory, "new-authz"):
+                regr = RegistrationResourceWithNewAuthzrURI(
+                    new_authzr_uri=acme.directory.new_authz,
+                    body={},
+                    uri=regr.uri)
+            else:
+                regr = messages.RegistrationResource(
+                    body={},
+                    uri=regr.uri)
+            regr_file.write(regr.json_dumps())
+
+    def _update_meta(self, account, dir_path):
+        with open(self._metadata_path(dir_path), "w") as metadata_file:
+            metadata_file.write(account.meta.json_dumps())
